@@ -7,7 +7,7 @@ from urlauth.models import AuthKey
 
 from account.util import email_template
 
-account_created = Signal(providing_args=['user'])
+account_created = Signal(providing_args=['user', 'request'])
 
 def key_user_found_handler(key, user, **kwargs):
     extra = key.extra
@@ -23,7 +23,7 @@ def key_user_found_handler(key, user, **kwargs):
     if user.is_active:
         if 'new_email' == action:
             if 'email' in extra:
-                user.email = args['email']
+                user.email = extra['email']
                 user.save()
 
 
